@@ -5,11 +5,11 @@
 # Release 2020-10-12
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.2
+MAKERESOLVEDEB_VERSION=1.3
 
 check_command() {
     echo -n "Checking for ${1}..."
-    if [ ! -x "$(command -v $1)" ]; then
+    if [[ ! -x "$(command -v $1)" ]]; then
 	echo "Missing! Sorry, seed '$1' to continue."
 	exit 1
     fi
@@ -17,7 +17,7 @@ check_command() {
 }
 
 copy_object() {
-    if [ -e "$1" ] ; then
+    if [[ -e "$1" ]] ; then
 	#echo "[COPY] $1 [TO] $2"
 	if ! cp -rp "$1" "$2";
 	then
@@ -29,13 +29,20 @@ copy_object() {
     fi
 }
 
+assert_object() {
+    if ! [[ -e "$1" ]] ; then
+	echo "[ERROR: MISSING] $1"
+	ERRORS=$((ERRORS+1))
+    fi
+}
+
 link_object() {
     #echo "[LINK] $2 [TO] $1"
     ln -s "$1" "$2"
 }
 
 create_directory() {
-    if [ -e "$1" ] ; then
+    if [[ -e "$1" ]] ; then
 	echo "[ERROR: DIRECTORY EXISTS] $1"
 	ERRORS=$((ERRORS+1))
     else
@@ -45,7 +52,7 @@ create_directory() {
 }
 
 createf_directory() {
-    if [ -e "${1}" ] ; then
+    if [[ -e "${1}" ]] ; then
 	chmod a+w -R ${1}
 	rm -rf ${1}
     fi
@@ -53,7 +60,7 @@ createf_directory() {
 }
 
 remove_directory() {
-    if [ -e "${1}" ] ; then
+    if [[ -e "${1}" ]] ; then
 	chmod a+w -R ${1}
 	rm -rf ${1}
     else
@@ -63,7 +70,7 @@ remove_directory() {
 }
 
 extract_tgz() {
-    if [ -f "$1" ] ; then
+    if [[ -f "$1" ]] ; then
 	#echo "[EXTRACT] $1 [TO] $2/$3"
 	tar -zxf "$1" -C "$2" "$3"
     else
@@ -73,7 +80,7 @@ extract_tgz() {
 }
 
 make_executable() {
-    if [ -e "$1" ] ; then
+    if [[ -e "$1" ]] ; then
 	#echo "[MAKE EXECUTABLE] $1"
 	chmod a+x "$1"
     else
@@ -94,6 +101,7 @@ Conflicts: ${DEB_CONFLICTS}
 EOF
     echo "#!/bin/sh" > ${DEB_DIR}/DEBIAN/postinst
     echo "#!/bin/sh" > ${DEB_DIR}/DEBIAN/postrm
+    create_directory ${DEB_DIR}/usr/share/applications/
 }
 
 close_deb() {
@@ -226,6 +234,53 @@ EOF
     fi
 }
 
+process16braw() {
+    if ! [[ -e ${UNPACK_DIR}/BlackmagicRAWPlayer ]]; then
+	return;
+    fi
+    echo "Adding BlackmagicRAWPlayer"
+
+    copy_object ${UNPACK_DIR}/BlackmagicRAWPlayer ${RESOLVE_BASE_DIR}
+
+    assert_object ${DEB_DIR}/opt/resolve/graphics/blackmagicraw-player_256x256_apps.png
+    assert_object ${DEB_DIR}/opt/resolve/BlackmagicRAWPlayer/BlackmagicRAWPlayer
+    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-braw-player.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Exec=/opt/resolve/BlackmagicRAWPlayer/BlackmagicRAWPlayer
+Icon=/opt/resolve/graphics/blackmagicraw-player_256x256_apps.png
+Name=Blackmagic RAW Player
+Terminal=false
+MimeType=application/x-braw-clip;application/x-braw-sidecar
+Type=Application
+StartupNotify=true
+Categories=AudioVideo
+EOF
+
+    if ! [[ -e ${UNPACK_DIR}/BlackmagicRAWSpeedTest ]]; then
+	return;
+    fi
+    echo "Adding BlackmagicRAWSpeedTest"
+
+    copy_object ${UNPACK_DIR}/BlackmagicRAWSpeedTest ${RESOLVE_BASE_DIR}
+
+    assert_object ${DEB_DIR}/opt/resolve/graphics/blackmagicraw-speedtest_256x256_apps.png
+    assert_object ${DEB_DIR}/opt/resolve/BlackmagicRAWSpeedTest/BlackmagicRAWSpeedTest
+    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-braw-speedtest.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Exec=/opt/resolve/BlackmagicRAWSpeedTest/BlackmagicRAWSpeedTest
+Icon=/opt/resolve/graphics/blackmagicraw-speedtest_256x256_apps.png
+Name=Blackmagic RAW Speed Test
+Terminal=false
+Type=Application
+StartupNotify=true
+Categories=AudioVideo
+EOF
+}
+
 echo "MakeResolveDeb ${MAKERESOLVEDEB_VERSION}"
 
 # Check argument
@@ -317,11 +372,13 @@ case $RESOLVE_VERSION in
     16.*)
 	echo "Using Resolve 16 conversion process"
 	process16
+	process16braw
 	;;
     *)
 	echo "Unknown Resolve version"
 	echo "Trying Resolve 16 conversion process"
 	process16
+	process16braw
 	;;
 esac
 
@@ -335,7 +392,7 @@ SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="066
 EOF
 
 # Create desktop shortcuts
-create_directory ${DEB_DIR}/usr/share/applications/
+assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Resolve.png
 cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
 [Desktop Entry]
 Version=1.0
@@ -349,6 +406,7 @@ Type=Application
 StartupNotify=true
 Categories=AudioVideo
 EOF
+assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Panels.png
 cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-panel-setup.desktop <<EOF
 [Desktop Entry]
 Version=1.0
